==> dde-dock_5.4.10.orig.tar.xz: dde-dock-5.4.10/plugins/overlay-warning/overlay-warning-plugin.h <==
/*
 * Copyright (C) 2011 ~ 2018 Deepin Technology Co., Ltd.
 *
 * Author:     sbw <sbw@sbw.so>
 *             listenerri <listenerri@gmail.com>
 *
 * Maintainer: listenerri <listenerri@gmail.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef OVERLAY_WARNING_PLUGIN_H
#define OVERLAY_WARNING_PLUGIN_H

#include "pluginsiteminterface.h"
#include "overlaywarningwidget.h"
#include "../widgets/tipswidget.h"

#include <QLabel>

namespace Dtk {
    namespace Widget {
        class DDialog;
    }
}

class OverlayWarningPlugin : public QObject, PluginsItemInterface
{
    Q_OBJECT
    Q_INTERFACES(PluginsItemInterface)
    Q_PLUGIN_METADATA(IID "com.deepin.dock.PluginsItemInterface" FILE "overlay-warning.json")

public:
    explicit OverlayWarningPlugin(QObject *parent = nullptr);

    const QString pluginName() const override;
    const QString pluginDisplayName() const override;
    void init(PluginProxyInterface *proxyInter) override;

    void pluginStateSwitched() override;
    bool pluginIsAllowDisable() override { return false; }
    bool pluginIsDisable() override;

    QWidget *itemWidget(const QString &itemKey) override;
    QWidget *itemTipsWidget(const QString &itemKey) override;
    const QString itemCommand(const QString &itemKey) override;
    void displayModeChanged(const Dock::DisplayMode displayMode) override;

    int itemSortKey(const QString &itemKey) override;
    void setSortKey(const QString &itemKey, const int order) override;

private:
    void loadPlugin();
    bool isOverlayRoot();

private slots:
    void showCloseOverlayDialogPre();
    void showCloseOverlayDialog();

private:
    bool m_pluginLoaded;

    OverlayWarningWidget *m_warningWidget;
    QTimer *m_showDisableOverlayDialogTimer;
};

#endif // OVERLAY_WARNING_PLUGIN_H

==> dde-dock_5.5.67.orig.tar.xz: dde-dock-5.5.67/plugins/overlay-warning/overlay-warning-plugin.h <==
/*
 * Copyright (C) 2011 ~ 2018 Deepin Technology Co., Ltd.
 *
 * Author:     sbw <sbw@sbw.so>
 *             listenerri <listenerri@gmail.com>
 *
 * Maintainer: listenerri <listenerri@gmail.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef OVERLAY_WARNING_PLUGIN_H
#define OVERLAY_WARNING_PLUGIN_H

#include "pluginsiteminterface.h"
#include "overlaywarningwidget.h"
#include "../widgets/tipswidget.h"

#include <QLabel>

namespace Dtk {
    namespace Widget {
        class DDialog;
    }
}

class OverlayWarningPlugin : public QObject, PluginsItemInterface
{
    Q_OBJECT
    Q_INTERFACES(PluginsItemInterface)
    Q_PLUGIN_METADATA(IID "com.deepin.dock.PluginsItemInterface" FILE "overlay-warning.json")

public:
    explicit OverlayWarningPlugin(QObject *parent = nullptr);

    const QString pluginName() const override;
    const QString pluginDisplayName() const override;
    void init(PluginProxyInterface *proxyInter) override;

    void pluginStateSwitched() override;
    bool pluginIsAllowDisable() override { return false; }
    bool pluginIsDisable() override;

    QWidget *itemWidget(const QString &itemKey) override;
    QWidget *itemTipsWidget(const QString &itemKey) override;
    const QString itemCommand(const QString &itemKey) override;
    void displayModeChanged(const Dock::DisplayMode displayMode) override;

    int itemSortKey(const QString &itemKey) override;
    void setSortKey(const QString &itemKey, const int order) override;

private:
    void loadPlugin();
    bool isOverlayRoot();

private slots:
    void showCloseOverlayDialogPre();
    void showCloseOverlayDialog();

private:
    bool m_pluginLoaded;

    QScopedPointer<OverlayWarningWidget> m_warningWidget;
    QTimer *m_showDisableOverlayDialogTimer;
};

#endif // OVERLAY_WARNING_PLUGIN_H
